@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 ##############################################################################
 #
@@ -25,16 +26,38 @@ import requests
 
 __all__ = ["RestfulFHIR"]
 
+
 class RestfulFHIR:
-    
+    """General Set of REST Interactions for resources"""
+
     def search(self, base, resource, params):
         """Search FHIR Resources with specific criteria
-            Base : Service Root URL
-            Resource : resource type
-            Parames : extra search criteria
+            PARAMETERS:
+                base : Service Root URL
+                besource : resource type
+                params : extra search criteria
+            RETURNS:
+                response
         """
-        fhir_query = str(base) +'/'+ str(resource) +'?'+ str(params)
-        response = requests.get (fhir_query)
+
+        fhir_query = str(base) + '/' + str(resource) + '?' + str(params)
+        response = requests.get(fhir_query)
+        return response
+
+    def read(self, base, resource, resid):
+        """Read current status of the resource
+            PARAMETERS:
+                base : Service Root URL
+                besource : resource type
+                resid : unique resource identifier
+            RETURNS:
+                response
+                    200 : Found
+                    404 : Does not exist
+                    410 : Deleted resource
+                    
+        """
+
+        fhir_query = str(base) + '/' + str(resource) + '/' + str(resid)
+        response = requests.get(fhir_query)
         return response
-                
-    
